Skip to contents

This function negates the %in% operator. I really don't know why this is not a built-in operator in R rksfun

Usage

x %NOTIN% y

Arguments

x

A vector of values to check if they exist in y

y

A vector of values to check if x values exist in