R/util_fun.R
grapes-NOTIN-grapes.Rd
This function negates the %in% operator. I really don't know why this is not a built-in operator in R rksfun
x %NOTIN% y
A vector of values to check if they exist in y
A vector of values to check if x values exist in